@@ -2,8 +2,8 @@
  JSCommunicator
  http://jscommunicator.org
 
- Copyright (C) 2013  Daniel Pocock http://danielpocock.com
- Copyright (C) 2014  Juliana Louback http://julianalouback.com
+ Copyright (C) 2013-2015  Daniel Pocock http://danielpocock.com
+ Copyright (C) 2014       Juliana Louback http://julianalouback.com
 
  The JavaScript code in this page is free software: you can
  redistribute it and/or modify it under the terms of the GNU
@@ -107,7 +107,7 @@ window.JSCommManager = {
     // The essential credentials are the SIP URI and a password
     // Leave the password empty ('') if using client certificates
     // and make it null to force the login box to appear.
-    if(this.credentials.uri && this.credentials.sip_auth_password) {
+    if(this.credentials.uri && this.credentials.sip_auth_password!=null) {
       have_credentials = true;
     }
 
@@ -132,6 +132,25 @@ window.JSCommManager = {
       console.log("auth username has been automatically derived from the user SIP address: " + this.credentials.uri + " => " + this.credentials.sip_auth_user);
     }
 
+    // copy STUN and TURN server details into the pcConfig object
+    // for peer connection configuration
+    var ice_servers = [];
+    var stun_servers = JSCommSettings.stun_servers;
+    if(Object.prototype.toString.call(stun_servers) === '[object Array]') {
+      // for an array of STUN servers:
+      for(var i = 0; i < stun_servers.length; i++) {
+        var ice_server = {
+          'urls': stun_servers[i].server
+        };
+        ice_servers.push(ice_server);
+      }
+    } else {
+      // for just a single STUN server entry not in an array:
+      var ice_server = {
+        'urls': stun_servers.server
+      };
+      ice_servers.push(ice_server);
+    }
     // Apply the credentials from SIP settings to any TURN server configuration
     // that has no credentials yet
     var turn_servers = JSCommSettings.turn_servers;
@@ -142,6 +161,12 @@ window.JSCommManager = {
           turn_servers[i].username = this.credentials.sip_auth_user;
           turn_servers[i].password = this.credentials.sip_auth_password;
         }
+        var ice_server = {
+          'urls': turn_servers[i].server,
+          'username': turn_servers[i].username,
+          'credential': turn_servers[i].password
+        };
+        ice_servers.push(ice_server);
       }
     } else {
       // for just a single TURN server entry not in an array:
@@ -149,7 +174,16 @@ window.JSCommManager = {
         turn_servers.username = this.credentials.sip_auth_user;
         turn_servers.password = this.credentials.sip_auth_password;
       }
+      var ice_server = {
+        'urls': turn_servers.server,
+        'username': turn_servers.username,
+        'credential': turn_servers.password
+      };
+      ice_servers.push(ice_server);
     }
+    this.pcConfig = {
+      'iceServers': ice_servers
+    };
 
     // Apply the user credentials from our local object back to
     // the main settings object used to configure the JsSIP stack
@@ -195,7 +229,7 @@ window.JSCommManager = {
     this.phone.on('newTransaction', function(e) {
       // TODO: map JsSIP session to some local session definition
       console.log("newTransaction");
-      var tx = e.data.transaction;
+      var tx = e.transaction;
       if(tx && tx.request_sender && tx.request_sender.applicant &&
           tx.request_sender.applicant.direction == "outgoing") {
         console.log("outgoing call");
@@ -321,7 +355,7 @@ window.JSCommManager = {
 
   session_start : function(e) {
 
-    var call = e.data.session;
+    var call = e.session;
 
     if(this.current_session != null) {
       console.log("rejecting new session, a session is already active");
@@ -354,10 +388,12 @@ window.JSCommManager = {
       Arbiter.publish("jsc/call/outgoing", peer_uri, {async:true});
     }
 
-    var with_video = (call.getLocalStreams().length > 0 &&
-                      call.getLocalStreams()[0].getVideoTracks().length > 0) ||
-                     (call.getRemoteStreams().length > 0 &&
-                      call.getRemoteStreams()[0].getVideoTracks().length > 0);
+    var conn = call.connection;
+    var with_video = conn != null &&
+                     ((conn.getLocalStreams().length > 0 &&
+                      conn.getLocalStreams()[0].getVideoTracks().length > 0) ||
+                     (conn.getRemoteStreams().length > 0 &&
+                      conn.getRemoteStreams()[0].getVideoTracks().length > 0));
 
     JSCommUI.session_start(status, peer_name, peer_display, peer_uri, with_video);
 
@@ -372,7 +408,7 @@ window.JSCommManager = {
     });
 
     call.on('failed', function(e) {
-      var cause = e.data.cause, response = e.data.response;
+      var cause = e.cause, response = e.response;
       JSCommUI.session_failed(cause);
       delete JSCommManager.current_session;
       // Signal that a call failed
@@ -380,22 +416,28 @@ window.JSCommManager = {
       Arbiter.publish("jsc/ua/idle", null, {async:true});
     });
 
-    var handleConfirmed = function(e) {
+    call.on('accepted', function(e) {
+      JSCommUI.session_accepted(call, e);
+    });
+
+    call.on('confirmed', function(e) {
       JSCommUI.session_connect(call, e);
       // Signal that a call connected
       Arbiter.publish("jsc/call/connected", null, {async:true});
-    };
-    // The 'started' event was generated by JsSIP < 0.4.0
-    // whereas later versions send 'accepted' and 'confirmed' events
-    // Discussed in https://github.com/versatica/JsSIP/issues/239
-    // One of these two lines will log an error but it proceeds anyway
-    console.log('only one of the event handlers "confirmed" or "started" will be registered and the other generates a log error which can be ignored');
-    call.on('confirmed', handleConfirmed);
-    call.on('started', handleConfirmed);
+    });
+
+    call.on('addstream', function(e) {
+      console.log('addstream callback');
+      JSCommUI.session_add_stream(e);
+    });
+
+    call.on('removestream', function(e) {
+      console.log('removestream callback (not implemented)'); // FIXME
+    });
 
     call.on('newDTMF', function(e) {
-      if (e.data.originator === 'remote') {
-        dtmf_char = e.data.dtmf.tone;
+      if (e.originator === 'remote') {
+        dtmf_char = e.dtmf.tone;
         JSCommUI.incoming_dtmf(dtmf_char);
         // Signal that a DTMF tone arrived
         Arbiter.publish("jsc/call/dtmf", dtmf_char, {async:true});
@@ -435,8 +477,16 @@ window.JSCommManager = {
       }
       this.phone.call(destination_address, {
         mediaConstraints: { audio: true, video: with_video },
-        RTCConstraints: {"optional": [{'DtlsSrtpKeyAgreement': 'true'}]},
-        turn_servers: this.JsSIPSettings.turn_servers,
+        rtcConstraints: {
+          "optional": [
+            {'DtlsSrtpKeyAgreement': 'true'}
+          ]
+        },
+        pcConfig: this.pcConfig,
+        rtcOfferConstraints: {
+          OfferToReceiveAudio: 1,
+          OfferToReceiveVideo: 1
+        },
         extraHeaders: extra_headers
       });
     } catch(e){
@@ -457,7 +507,19 @@ window.JSCommManager = {
   answer_call : function(with_video) {
     this.current_session.answer(
       { mediaConstraints:
-          { audio: true, video: with_video }
+          { audio: true, video: with_video },
+        pcConfig: this.pcConfig,
+        rtcConstraints: {
+          "optional": [
+            {'DtlsSrtpKeyAgreement': 'true'}
+          ]
+        },
+        rtcOfferConstraints: {
+          OfferToReceiveAudio: 1,
+          OfferToReceiveVideo: 1
+        },
+        rtcAnswerConstraints: {
+        }
       });
   },
 
