@@ -2,8 +2,8 @@
  JSCommunicator
  http://jscommunicator.org
 
- Copyright (C) 2013  Daniel Pocock http://danielpocock.com
- Copyright (C) 2014  Juliana Louback http://julianalouback.com
+ Copyright (C) 2013-2015  Daniel Pocock http://danielpocock.com
+ Copyright (C) 2014       Juliana Louback http://julianalouback.com
 
  The JavaScript code in this page is free software: you can
  redistribute it and/or modify it under the terms of the GNU
@@ -451,6 +451,13 @@ window.JSCommUI = {
     }
   },
 
+  session_accepted : function(call, e) {
+    localStream = call.connection.getLocalStreams()[0];
+    var selfView = document.getElementById('selfView');
+    JsSIP.rtcninja.attachMediaStream(selfView, localStream);
+    selfView.volume = 0;
+  },
+
   session_connect : function(call, e) {
     clearInterval(JSCommUI.soundLoop);
     soundPlayer.pause();
@@ -464,25 +471,26 @@ window.JSCommUI = {
     $("#session-actions button").hide();
     $(".session-active").show();
 
-    var local_stream_count = call.getLocalStreams().length;
-    var remote_stream_count = call.getRemoteStreams().length;
+    var conn = call.connection;
+    var local_stream_count = conn.getLocalStreams().length;
+    var remote_stream_count = conn.getRemoteStreams().length;
 
     console.log("local stream count = " + local_stream_count +
                 ", remote stream count = " + remote_stream_count);
 
-    if(local_stream_count > 0) {
-      $('#selfView').attr('src', window.URL.createObjectURL(call.getLocalStreams()[0]));
+    /*if(local_stream_count > 0) {
+      $('#selfView').attr('src', window.URL.createObjectURL(conn.getLocalStreams()[0]));
       $('#selfView').attr('volume', 0);
-    }
+    }*/
 
-    if(remote_stream_count > 0) {
-      $('#remoteView').attr('src',  window.URL.createObjectURL(call.getRemoteStreams()[0]));
-    }
+    /*if(remote_stream_count > 0) {
+      $('#remoteView').attr('src',  window.URL.createObjectURL(conn.getRemoteStreams()[0]));
+    }*/
 
     var with_video = (local_stream_count > 0 &&
-                      call.getLocalStreams()[0].getVideoTracks().length > 0) ||
+                      conn.getLocalStreams()[0].getVideoTracks().length > 0) ||
                      (remote_stream_count > 0 &&
-                      call.getRemoteStreams()[0].getVideoTracks().length > 0);
+                      conn.getRemoteStreams()[0].getVideoTracks().length > 0);
 
     if(with_video) {
       $('#video-session').show();
@@ -492,6 +500,13 @@ window.JSCommUI = {
     }
   },
 
+  session_add_stream : function(e) {
+    var remoteStream = e.stream;
+    //$('#remoteView').attr('src',  window.URL.createObjectURL(stream));
+    var remoteView = document.getElementById('remoteView');
+    JsSIP.rtcninja.attachMediaStream(remoteView, remoteStream);
+  },
+
   session_end : function() {
     this.session_cleanup();
   },
