@@ -2,7 +2,7 @@
  JSCommunicator
  http://jscommunicator.org
 
- Copyright (C) 2013  Daniel Pocock http://danielpocock.com
+ Copyright (C) 2013-2015  Daniel Pocock http://danielpocock.com
 
  The JavaScript code in this page is free software: you can
  redistribute it and/or modify it under the terms of the GNU
@@ -20,11 +20,7 @@
 
 function WebRTCSupported() {
 
-  if (navigator.webkitGetUserMedia) {
-    return true;
-  } else if (navigator.mozGetUserMedia) {
-    return true;
-  } else if (navigator.getUserMedia) {
+  if (JsSIP.rtcninja.hasWebRTC()) {
     return true;
   } else {
     console.error("WebRTC support not found");
